@@ -1,6 +1,6 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
-/* @(#) $Header: /sources/phpprintipp/phpprintipp/CupsPrintIPP.php,v 1.5 2006/01/02 20:42:02 harding Exp $
+/* @(#) $Header: /sources/phpprintipp/phpprintipp/CupsPrintIPP.php,v 1.6 2006/01/06 18:08:22 harding Exp $
  *
  * Version: 0.1
  * Class PrintIPP - Send extended IPP requests.
@@ -113,7 +113,7 @@ class CupsPrintIPP extends ExtendedPrintIPP {
     // {{{ getPrinterAttributes()
     public function getPrinterAttributes() {
         
-        if(!parent::getPrinterAttributes())
+        if(!$result = parent::getPrinterAttributes())
             return FALSE;
         if(!isset($this->printer_attributes))
             return FALSE;
@@ -126,7 +126,7 @@ class CupsPrintIPP extends ExtendedPrintIPP {
             $this->printer_attributes->printer_type->$index = $table[$i];
             }
 
-    return true;
+    return $result;
     }
     // }}}
     
