@@ -83,7 +83,7 @@ function __autoload($class_name) {
 //$ipp = new ExtendedPrintIPP(); // extended IPP
 $ipp = new CupsPrintIPP(); // extended IPP with CUPS specific stuff
 
-$ipp->debug_level = 3; // Debugging very verbose
+//$ipp->debug_level = 3; // Debugging very verbose
 
 $ipp->setLog('/tmp/printipp','file',1); // logging almost quiet
 $ipp->setLog('/tmp/printipp','file',2); // logging verbose
@@ -108,12 +108,23 @@ $ipp->setAuthentification($user,$password); // username & password
 
 $j = 0;
 $test = 1;
+
+
+/* printing a large file */
+
+echo "<br /><br /><br />TEST ".$test++."<br />";
+echo "OPERATION  ".$j++."<br />";
+$ipp->setData('testfiles/photo.jpg');
+echo "Printing a large file: ". $ipp->PrintJob() . "<br />";
+printf('$ipp->status[0] = %s <br /><br />', $ipp->status[0]);
+
+
 /* getting printer's attributes */
 
 echo "<br /><br /><br />TEST ".$test++."<br />";
 echo "OPERATION  ".$j++."<br />";
 echo "Getting Printer's attributes: ". $ipp->getPrinterAttributes() . "<br />";
-printf('$ipp->status[0] = %s <br /><br />', $ipp->status[0]);
+printf('$ipp->status[%s] = %s <br /><br />', count($ipp->status) -1,$ipp->status[count($ipp->status) -1]);
 echo "Printer's attributes :<pre>\n"; print_r($ipp->printer_attributes); echo "</pre>";
 
 /* getting printers (CUPS extention) */
@@ -424,7 +435,7 @@ echo "Job State Reason: ".$ipp->job_attributes->job_state_reasons->_value0."<br
 echo "<br /><br /><br /> TEST ".$test ++."<br />";
 
 echo "OPERATION ". $j ++ ."<br />";
-echo "Releasing the job for: ".$ipp->releaseJob($job,'indefinite')."<br />";
+echo "Releasing the job: ".$ipp->releaseJob($job,'indefinite')."<br />";
 echo "OPERATION ". $j ++ ."<br />";
 echo "Getting job state : ".$ipp->getJobAttributes($job)."<br />";
 echo "Job State: ".$ipp->job_attributes->job_state->_value0."<br />";
